@@ -60,6 +60,9 @@
 extern char *local_icaltimezone_location;
 extern gboolean local_icaltimezone_utc;
 
+void
+fill_appt_window(appt_win *apptw, char *action, char *par);
+
 enum {
     LOCATION,
     LOCATION_ENG,
@@ -163,14 +166,18 @@ set_time_sensitivity(appt_win *apptw)
         gtk_widget_set_sensitive(apptw->appEndTime_spin_mm, FALSE);
         gtk_widget_set_sensitive(apptw->appEndTimezone_button, FALSE);
         gtk_widget_set_sensitive(apptw->appDur_spin_hh, FALSE);
+        gtk_widget_set_sensitive(apptw->appDur_spin_hh_label, FALSE);
         gtk_widget_set_sensitive(apptw->appDur_spin_mm, FALSE);
+        gtk_widget_set_sensitive(apptw->appDur_spin_mm_label, FALSE);
         if (dur_act) {
             gtk_widget_set_sensitive(apptw->appEndDate_button, FALSE);
             gtk_widget_set_sensitive(apptw->appDur_spin_dd, TRUE);
+            gtk_widget_set_sensitive(apptw->appDur_spin_dd_label, TRUE);
         }
         else {
             gtk_widget_set_sensitive(apptw->appEndDate_button, TRUE);
             gtk_widget_set_sensitive(apptw->appDur_spin_dd, FALSE);
+            gtk_widget_set_sensitive(apptw->appDur_spin_dd_label, FALSE);
         }
     }
     else {
@@ -183,8 +190,11 @@ set_time_sensitivity(appt_win *apptw)
             gtk_widget_set_sensitive(apptw->appEndTime_spin_mm, FALSE);
             gtk_widget_set_sensitive(apptw->appEndTimezone_button, FALSE);
             gtk_widget_set_sensitive(apptw->appDur_spin_dd, TRUE);
+            gtk_widget_set_sensitive(apptw->appDur_spin_dd_label, TRUE);
             gtk_widget_set_sensitive(apptw->appDur_spin_hh, TRUE);
+            gtk_widget_set_sensitive(apptw->appDur_spin_hh_label, TRUE);
             gtk_widget_set_sensitive(apptw->appDur_spin_mm, TRUE);
+            gtk_widget_set_sensitive(apptw->appDur_spin_mm_label, TRUE);
         }
         else {
             gtk_widget_set_sensitive(apptw->appEndDate_button, TRUE);
@@ -192,8 +202,11 @@ set_time_sensitivity(appt_win *apptw)
             gtk_widget_set_sensitive(apptw->appEndTime_spin_mm, TRUE);
             gtk_widget_set_sensitive(apptw->appEndTimezone_button, TRUE);
             gtk_widget_set_sensitive(apptw->appDur_spin_dd, FALSE);
+            gtk_widget_set_sensitive(apptw->appDur_spin_dd_label, FALSE);
             gtk_widget_set_sensitive(apptw->appDur_spin_hh, FALSE);
+            gtk_widget_set_sensitive(apptw->appDur_spin_hh_label, FALSE);
             gtk_widget_set_sensitive(apptw->appDur_spin_mm, FALSE);
+            gtk_widget_set_sensitive(apptw->appDur_spin_mm_label, FALSE);
         }
     }
 }
@@ -201,22 +214,60 @@ set_time_sensitivity(appt_win *apptw)
 void
 set_repeat_sensitivity(appt_win *apptw)
 {
-    gint freq;
+    gint freq, i;
     
-    freq = gtk_combo_box_get_active((GtkComboBox *)apptw->appRecur_cb);
+    freq = gtk_combo_box_get_active((GtkComboBox *)apptw->appRecur_freq_cb);
     if (freq == XFICAL_FREQ_NONE) {
-        gtk_widget_set_sensitive(apptw->appRecur_repeat_rb, FALSE);
+        gtk_widget_set_sensitive(apptw->appRecur_limit_rb, FALSE);
         gtk_widget_set_sensitive(apptw->appRecur_count_rb, FALSE);
         gtk_widget_set_sensitive(apptw->appRecur_count_spin, FALSE);
+        gtk_widget_set_sensitive(apptw->appRecur_count_label, FALSE);
         gtk_widget_set_sensitive(apptw->appRecur_until_rb, FALSE);
         gtk_widget_set_sensitive(apptw->appRecur_until_button, FALSE);
+        for (i=0; i <= 6; i++) {
+            gtk_widget_set_sensitive(apptw->appRecur_byday_cb[i], FALSE);
+            gtk_widget_set_sensitive(apptw->appRecur_byday_spin[i], FALSE);
+        }
+        gtk_widget_set_sensitive(apptw->appRecur_int_spin, FALSE);
+        gtk_widget_set_sensitive(apptw->appRecur_int_spin_label1, FALSE);
+        gtk_widget_set_sensitive(apptw->appRecur_int_spin_label2, FALSE);
     }
     else {
-        gtk_widget_set_sensitive(apptw->appRecur_repeat_rb, TRUE);
+        gtk_widget_set_sensitive(apptw->appRecur_limit_rb, TRUE);
         gtk_widget_set_sensitive(apptw->appRecur_count_rb, TRUE);
-        gtk_widget_set_sensitive(apptw->appRecur_count_spin, TRUE);
+        if (gtk_toggle_button_get_active(
+                GTK_TOGGLE_BUTTON(apptw->appRecur_count_rb))) {
+            gtk_widget_set_sensitive(apptw->appRecur_count_spin, TRUE);
+            gtk_widget_set_sensitive(apptw->appRecur_count_label, TRUE);
+        }
+        else {
+            gtk_widget_set_sensitive(apptw->appRecur_count_spin, FALSE);
+            gtk_widget_set_sensitive(apptw->appRecur_count_label, FALSE);
+        }
         gtk_widget_set_sensitive(apptw->appRecur_until_rb, TRUE);
-        gtk_widget_set_sensitive(apptw->appRecur_until_button, TRUE);
+        if (gtk_toggle_button_get_active(
+                GTK_TOGGLE_BUTTON(apptw->appRecur_until_rb))) {
+            gtk_widget_set_sensitive(apptw->appRecur_until_button, TRUE);
+        }
+        else {
+            gtk_widget_set_sensitive(apptw->appRecur_until_button, FALSE);
+        }
+        for (i=0; i <= 6; i++) {
+            gtk_widget_set_sensitive(apptw->appRecur_byday_cb[i], TRUE);
+        }
+        if (freq == XFICAL_FREQ_MONTHLY || freq == XFICAL_FREQ_YEARLY) {
+            for (i=0; i <= 6; i++) {
+                gtk_widget_set_sensitive(apptw->appRecur_byday_spin[i], TRUE);
+            }
+        }
+        else {
+            for (i=0; i <= 6; i++) {
+                gtk_widget_set_sensitive(apptw->appRecur_byday_spin[i], FALSE);
+            }
+        }
+        gtk_widget_set_sensitive(apptw->appRecur_int_spin, TRUE);
+        gtk_widget_set_sensitive(apptw->appRecur_int_spin_label1, TRUE);
+        gtk_widget_set_sensitive(apptw->appRecur_int_spin_label2, TRUE);
     }
 }
 
@@ -248,6 +299,40 @@ appDur_checkbutton_clicked_cb(GtkCheckButton *cb, gpointer user_data)
     mark_appointment_changed((appt_win *)user_data);
 }
 
+void
+app_recur_checkbutton_clicked_cb(GtkCheckButton *checkbutton
+        , gpointer user_data)
+{
+    mark_appointment_changed((appt_win *)user_data);
+    set_repeat_sensitivity((appt_win *)user_data);
+}
+
+void
+app_recur_feature_checkbutton_clicked_cb(GtkCheckButton *checkbutton
+        , gpointer user_data)
+{
+    appt_win *apptw=(appt_win *)user_data;
+
+    mark_appointment_changed((appt_win *)user_data);
+    if (gtk_toggle_button_get_active(
+            GTK_TOGGLE_BUTTON(apptw->appRecur_feature_normal_rb))) {
+        gtk_widget_hide(apptw->appRecur_int_label);
+        gtk_widget_hide(apptw->appRecur_int_hbox);
+        gtk_widget_hide(apptw->appRecur_byday_label);
+        gtk_widget_hide(apptw->appRecur_byday_hbox);
+        gtk_widget_hide(apptw->appRecur_byday_spin_label);
+        gtk_widget_hide(apptw->appRecur_byday_spin_hbox);
+    }
+    else {
+        gtk_widget_show(apptw->appRecur_int_label);
+        gtk_widget_show(apptw->appRecur_int_hbox);
+        gtk_widget_show(apptw->appRecur_byday_label);
+        gtk_widget_show(apptw->appRecur_byday_hbox);
+        gtk_widget_show(apptw->appRecur_byday_spin_label);
+        gtk_widget_show(apptw->appRecur_byday_spin_hbox);
+    }
+}
+
 void
 app_checkbutton_clicked_cb(GtkCheckButton *checkbutton, gpointer user_data)
 {
@@ -404,16 +489,17 @@ orage_validate_datetime(appt_win *apptw, appt_data *appt)
 }
 
 /*
- * fill_appt
+ * fill_appt_from_apptw
  * This function fills an appointment with the content of an appointment window
  */
 gboolean
-fill_appt(appt_data *appt, appt_win *apptw)
+fill_appt_from_apptw(appt_data *appt, appt_win *apptw)
 {
     GtkTextIter start, end;
     const char *time_format="%H:%M";
     struct tm current_t;
     gchar starttime[6], endtime[6];
+    gint i;
 
     /*Get the title */
     appt->title = g_strdup(gtk_entry_get_text(
@@ -471,11 +557,13 @@ fill_appt(appt_data *appt, appt_win *apptw)
         return(FALSE);
 
     /* Get the availability */
-    appt->availability = gtk_combo_box_get_active((GtkComboBox *)apptw->appAvailability_cb);
+    appt->availability = gtk_combo_box_get_active(
+            (GtkComboBox *)apptw->appAvailability_cb);
 
     /* Get the notes */
     gtk_text_buffer_get_bounds(
-            gtk_text_view_get_buffer((GtkTextView *)apptw->appNote_textview), &start, &end);
+            gtk_text_view_get_buffer((GtkTextView *)apptw->appNote_textview)
+            , &start, &end);
     appt->note = gtk_text_iter_get_text(&start, &end);
 
     /* Get when the reminder will show up */
@@ -488,17 +576,24 @@ fill_appt(appt_data *appt, appt_win *apptw)
                     ;
 
     /* Which sound file will be played */
-    appt->sound = g_strdup(gtk_entry_get_text((GtkEntry *)apptw->appSound_entry));
+    appt->sound = g_strdup(gtk_entry_get_text(
+                (GtkEntry *)apptw->appSound_entry));
 
     /* Get if the alarm will repeat until someone shuts it off */
-    appt->alarmrepeat = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(apptw->appSoundRepeat_checkbutton));
+    appt->alarmrepeat = gtk_toggle_button_get_active(
+            GTK_TOGGLE_BUTTON(apptw->appSoundRepeat_checkbutton));
 
     /* Get the recurrence */
-    appt->freq = gtk_combo_box_get_active((GtkComboBox *)apptw->appRecur_cb);
+    appt->freq = gtk_combo_box_get_active(
+            (GtkComboBox *)apptw->appRecur_freq_cb);
+
+    /* Get the recurrence interval */
+    appt->interval = gtk_spin_button_get_value_as_int(
+            GTK_SPIN_BUTTON(apptw->appRecur_int_spin));
 
     /* Get the recurrence ending */
     if (gtk_toggle_button_get_active(
-                GTK_TOGGLE_BUTTON(apptw->appRecur_repeat_rb))) {
+                GTK_TOGGLE_BUTTON(apptw->appRecur_limit_rb))) {
         appt->recur_limit = 0;    /* no limit */
         appt->recur_count = 0;    /* special: means no repeat count limit */
         appt->recur_until[0] = 0; /* special: means no until time limit */
@@ -507,7 +602,7 @@ fill_appt(appt_data *appt, appt_win *apptw)
                 GTK_TOGGLE_BUTTON(apptw->appRecur_count_rb))) {
         appt->recur_limit = 1;    /* count limit */
         appt->recur_count = gtk_spin_button_get_value_as_int(
-                    GTK_SPIN_BUTTON(apptw->appRecur_count_spin));
+                GTK_SPIN_BUTTON(apptw->appRecur_count_spin));
         appt->recur_until[0] = 0; /* special: means no until time limit */
     }
     else if (gtk_toggle_button_get_active(
@@ -518,11 +613,20 @@ fill_appt(appt_data *appt, appt_win *apptw)
         current_t = display_to_year_month_day(gtk_button_get_label(
                 GTK_BUTTON(apptw->appRecur_until_button)));
         g_sprintf(appt->recur_until, XFICAL_APPT_TIME_FORMAT
-            , current_t.tm_year + 1900, current_t.tm_mon + 1, current_t.tm_mday
-            , 0, 0, 0);
+                , current_t.tm_year + 1900, current_t.tm_mon + 1
+                , current_t.tm_mday, 0, 0, 0);
     }
     else
-        g_warning("fill_appt: coding error, illegal recurrence");
+        g_warning("fill_appt_from_apptw: coding error, illegal recurrence");
+
+    /* Get the recurrence weekdays */
+    for (i=0; i <= 6; i++) {
+        appt->recur_byday[i] = gtk_toggle_button_get_active(
+                GTK_TOGGLE_BUTTON(apptw->appRecur_byday_cb[i]));
+    /* Get the recurrence weekday selection for month/yearly case */
+        appt->recur_byday_cnt[i] = gtk_spin_button_get_value_as_int(
+                GTK_SPIN_BUTTON(apptw->appRecur_byday_spin[i]));
+    }
 
     return(TRUE);
 }
@@ -539,7 +643,7 @@ save_xfical_from_appt_win(appt_win *apptw)
     gboolean ok = FALSE;
     appt_data *appt = xfical_appt_alloc();
 
-    if (fill_appt(appt, apptw)) {
+    if (fill_appt_from_apptw(appt, apptw)) {
         /* Here we try to save the event... */
         if (xfical_file_open()) {
             if (apptw->appointment_add) {
@@ -548,7 +652,7 @@ save_xfical_from_appt_win(appt_win *apptw)
                 if (ok) {
                     apptw->appointment_add = FALSE;
                     gtk_widget_set_sensitive(apptw->appDuplicate, TRUE);
-                    g_message("Added: %s", apptw->xf_uid);
+                    g_message("Orage **: Added: %s", apptw->xf_uid);
                 }
                 else
                     g_warning("Addition failed: %s", apptw->xf_uid);
@@ -556,7 +660,7 @@ save_xfical_from_appt_win(appt_win *apptw)
             else {
                 ok = xfical_appt_mod(apptw->xf_uid, appt);
                 if (ok)
-                    g_message("Modified: %s", apptw->xf_uid);
+                    g_message("Orage **: Modified: %s", apptw->xf_uid);
                 else
                     g_warning("Modification failed: %s", apptw->xf_uid);
             }
@@ -631,7 +735,7 @@ delete_xfical_from_appt_win(appt_win *apptw)
                 result = xfical_appt_del(apptw->xf_uid);
                 xfical_file_close();
                 if (result)
-                    g_message("Removed: %s", apptw->xf_uid);
+                    g_message("Orage **: Removed: %s", apptw->xf_uid);
                 else
                     g_warning("Removal failed: %s", apptw->xf_uid);
             }
@@ -803,9 +907,6 @@ on_appStartEndTimezone_clicked_cb(GtkWidget *button, gpointer *user_data)
                     , -1);
         }
         /* then city translated and in base form used internally */
-        /*
-        g_print("TREE store: %s %s\n", _(tz.city[i]), tz.city[i]);
-        */
         gtk_tree_store_append(store, &iter2, &iter1);
         gtk_tree_store_set(store, &iter2
                 , LOCATION, _(tz.city[i]) 
@@ -850,11 +951,13 @@ on_appStartEndTimezone_clicked_cb(GtkWidget *button, gpointer *user_data)
                         result = 0;
                     else {
                         gtk_tree_model_get(model, &iter, LOCATION, &loc, -1);
-                        gtk_tree_model_get(model, &iter, LOCATION_ENG, &loc_eng, -1);
+                        gtk_tree_model_get(model, &iter, LOCATION_ENG
+                                , &loc_eng, -1);
                     }
                 else {
                     loc = g_strdup(gtk_button_get_label(GTK_BUTTON(button)));
-                    loc_eng = g_object_get_data(G_OBJECT(button), "LOCATION_ENG");
+                    loc_eng = g_object_get_data(G_OBJECT(button)
+                            , "LOCATION_ENG");
                 }
                 break;
             case 1:
@@ -1033,7 +1136,7 @@ fill_appt_window_get_appt(char *action, char *par)
             return(NULL);
         }
         if ((appt = xfical_appt_get(par)) == NULL) {
-            g_message("appointment not found");
+            g_message("Orage **: appointment not found");
             xfical_file_close();
             return(NULL);
         }
@@ -1055,8 +1158,9 @@ fill_appt_window(appt_win *apptw, char *action, char *par)
     appt_data *appt;
     struct tm *t;
     char *untildate_to_display;
+    int i;
 
-    g_message("%s appointment: %s", action, par);
+    g_message("Orage **: %s appointment: %s", action, par);
     if ((appt = fill_appt_window_get_appt(action, par)) == NULL) {
         g_error("fill_appt_window: Appointment initialization failed");
         return;
@@ -1138,11 +1242,12 @@ fill_appt_window(appt_win *apptw, char *action, char *par)
 
     /********************* RECURRENCE tab *********************/
     /* recurrence */
-    gtk_combo_box_set_active(GTK_COMBO_BOX(apptw->appRecur_cb), appt->freq);
+    gtk_combo_box_set_active(GTK_COMBO_BOX(apptw->appRecur_freq_cb)
+            , appt->freq);
     switch(appt->recur_limit) {
         case 0: /* no limit */
             gtk_toggle_button_set_active(
-                    GTK_TOGGLE_BUTTON(apptw->appRecur_repeat_rb), TRUE);
+                    GTK_TOGGLE_BUTTON(apptw->appRecur_limit_rb), TRUE);
             gtk_spin_button_set_value(
                     GTK_SPIN_BUTTON(apptw->appRecur_count_spin), (gdouble)1);
             t = orage_localtime();
@@ -1179,6 +1284,33 @@ fill_appt_window(appt_win *apptw, char *action, char *par)
                     appt->recur_limit);
     }
 
+    /* weekdays */
+    for (i=0; i <= 6; i++) {
+        gtk_toggle_button_set_active(
+                GTK_TOGGLE_BUTTON(apptw->appRecur_byday_cb[i])
+                , appt->recur_byday[i]);
+        /* which weekday of month / year */
+        gtk_spin_button_set_value(
+                GTK_SPIN_BUTTON(apptw->appRecur_byday_spin[i])
+                , (gdouble)appt->recur_byday_cnt[i]);
+    }
+
+    /* interval */
+    gtk_spin_button_set_value(
+            GTK_SPIN_BUTTON(apptw->appRecur_int_spin)
+            , (gdouble)appt->interval);
+
+    if (appt->interval > 1
+    || !appt->recur_byday[0] || !appt->recur_byday[1] || !appt->recur_byday[2] 
+    || !appt->recur_byday[3] || !appt->recur_byday[4] || !appt->recur_byday[5] 
+    || !appt->recur_byday[6]) {
+        gtk_toggle_button_set_active(
+                GTK_TOGGLE_BUTTON(apptw->appRecur_feature_advanced_rb), TRUE);
+    }
+    else {
+        gtk_toggle_button_set_active(
+                GTK_TOGGLE_BUTTON(apptw->appRecur_feature_normal_rb), TRUE);
+    }
     xfical_appt_free(appt);
 
     set_time_sensitivity(apptw);
@@ -1193,8 +1325,8 @@ create_appt_win_menu(appt_win *apptw)
 
     /* Menu bar */
     apptw->appMenubar = gtk_menu_bar_new();
-    gtk_box_pack_start(GTK_BOX(apptw->appVBox1), apptw->appMenubar,
-                        FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(apptw->appVBox1), apptw->appMenubar
+            , FALSE, FALSE, 0);
 
     /* File menu stuff */
     apptw->appFile_menu = xfcalendar_menu_new(_("_File"), apptw->appMenubar);
@@ -1359,24 +1491,27 @@ create_appt_win_tab_general(appt_win *apptw)
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(apptw->appDur_spin_dd), TRUE);
     gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox), apptw->appDur_spin_dd
             , FALSE, FALSE, 5);
-    label = gtk_label_new(_("days"));
-    gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox), label, FALSE, FALSE, 0);
+    apptw->appDur_spin_dd_label = gtk_label_new(_("days"));
+    gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox)
+            , apptw->appDur_spin_dd_label, FALSE, FALSE, 0);
     label = gtk_label_new(" ");
     gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox), label, FALSE, FALSE, 5);
     apptw->appDur_spin_hh = gtk_spin_button_new_with_range(0, 23, 1);
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(apptw->appDur_spin_hh), TRUE);
     gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox), apptw->appDur_spin_hh
             , FALSE, FALSE, 5);
-    label = gtk_label_new(_("hours"));
-    gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox), label, FALSE, FALSE, 0);
+    apptw->appDur_spin_hh_label = gtk_label_new(_("hours"));
+    gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox)
+            , apptw->appDur_spin_hh_label, FALSE, FALSE, 0);
     label = gtk_label_new(" ");
     gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox), label, FALSE, FALSE, 5);
     apptw->appDur_spin_mm = gtk_spin_button_new_with_range(0, 59, 5);
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(apptw->appDur_spin_mm), TRUE);
     gtk_box_pack_start(GTK_BOX(apptw->appDur_hbox), apptw->appDur_spin_mm
             , FALSE, FALSE, 5);
-    label = gtk_label_new(_("mins"));
-    gtk_box_pack_start(GTK_BOX (apptw->appDur_hbox), label, FALSE, FALSE, 0);
+    apptw->appDur_spin_mm_label = gtk_label_new(_("mins"));
+    gtk_box_pack_start(GTK_BOX (apptw->appDur_hbox)
+            , apptw->appDur_spin_mm_label, FALSE, FALSE, 0);
     xfcalendar_table_add_row(apptw->appTableGeneral
             , NULL, apptw->appDur_hbox, 5
             , (GtkAttachOptions) (GTK_FILL)
@@ -1409,6 +1544,7 @@ create_appt_win_tab_general(appt_win *apptw)
             , apptw->appNote, apptw->appNote_Scrolledwindow, 7
             , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
             , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL));
+    gtk_widget_grab_focus(apptw->appTitle_entry);
 }
 
 void
@@ -1478,63 +1614,137 @@ create_appt_win_tab_alarm(appt_win *apptw)
 void
 create_appt_win_tab_recurrence(appt_win *apptw)
 {
-    GtkWidget *label;
-    char *recur_array[RECUR_ARRAY_DIM] = {
-            _("None"), _("Daily"), _("Weekly"), _("Monthly"), _("Yearly")};
+    gint row=1, i;
+    char *recur_freq_array[RECUR_ARRAY_DIM] = {
+        _("None"), _("Daily"), _("Weekly"), _("Monthly"), _("Yearly")};
+    char *weekday_array[7] = {
+        _("Mon"), _("Tue"), _("Wed"), _("Thu"), _("Fri"), _("Sat"), _("Sun")};
 
     apptw->appTableRecur = xfcalendar_table_new(8, 2);
     apptw->appRecur_notebook_page = 
-        xfce_create_framebox_with_content(NULL, apptw->appTableRecur);
+            xfce_create_framebox_with_content(NULL, apptw->appTableRecur);
     apptw->appRecur_tab_label = gtk_label_new(_("Recurrence"));
 
     gtk_notebook_append_page(GTK_NOTEBOOK(apptw->appNotebook)
             , apptw->appRecur_notebook_page, apptw->appRecur_tab_label);
 
-    apptw->appRecur = gtk_label_new(_("Recurrence"));
-    apptw->appRecur_cb = gtk_combo_box_new_text();
-    xfcalendar_combo_box_append_array(apptw->appRecur_cb
-            , recur_array, RECUR_ARRAY_DIM);
+    apptw->appRecur_feature_label = gtk_label_new(_("Complexity"));
+    apptw->appRecur_feature_hbox = gtk_hbox_new(FALSE, 0);
+    apptw->appRecur_feature_normal_rb = gtk_radio_button_new_with_label(NULL
+            , _("Basic"));
+    gtk_box_pack_start(GTK_BOX(apptw->appRecur_feature_hbox)
+            , apptw->appRecur_feature_normal_rb, FALSE, FALSE, 15);
+    apptw->appRecur_feature_advanced_rb = 
+            gtk_radio_button_new_with_mnemonic_from_widget(
+                    GTK_RADIO_BUTTON(apptw->appRecur_feature_normal_rb)
+            , _("Advanced"));
+    gtk_box_pack_start(GTK_BOX(apptw->appRecur_feature_hbox)
+            , apptw->appRecur_feature_advanced_rb, FALSE, FALSE, 15);
     xfcalendar_table_add_row(apptw->appTableRecur
-            , apptw->appRecur, apptw->appRecur_cb, 1
+            , apptw->appRecur_feature_label, apptw->appRecur_feature_hbox, row++
+            , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
+            , (GtkAttachOptions) (0));
+    gtk_tooltips_set_tip(apptw->appTooltips, apptw->appRecur_feature_normal_rb
+            , _("Use this if you want regular repeating event"), NULL);
+    gtk_tooltips_set_tip(apptw->appTooltips, apptw->appRecur_feature_advanced_rb
+            , _("Use this if you need complex times like:\n Every second week or \n Every Saturday and Sunday or \n First Tuesday every month")
+            , NULL);
+
+    apptw->appRecur_freq_label = gtk_label_new(_("Frequency"));
+    apptw->appRecur_freq_cb = gtk_combo_box_new_text();
+    xfcalendar_combo_box_append_array(apptw->appRecur_freq_cb
+            , recur_freq_array, RECUR_ARRAY_DIM);
+    xfcalendar_table_add_row(apptw->appTableRecur
+            , apptw->appRecur_freq_label, apptw->appRecur_freq_cb, row++
             , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
             , (GtkAttachOptions) (GTK_FILL));
 
-    apptw->appRecur_repeat_rb = gtk_radio_button_new_with_label(NULL
+    apptw->appRecur_int_label = gtk_label_new(_("Interval"));
+    apptw->appRecur_int_hbox = gtk_hbox_new(FALSE, 0);
+    apptw->appRecur_int_spin_label1 = gtk_label_new(_("Each"));
+    gtk_box_pack_start(GTK_BOX(apptw->appRecur_int_hbox)
+            , apptw->appRecur_int_spin_label1, FALSE, FALSE, 0);
+    apptw->appRecur_int_spin = gtk_spin_button_new_with_range(1, 100, 1);
+    gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(apptw->appRecur_int_spin), TRUE);
+    gtk_box_pack_start(GTK_BOX(apptw->appRecur_int_hbox)
+            , apptw->appRecur_int_spin, FALSE, FALSE, 5);
+    apptw->appRecur_int_spin_label2 = gtk_label_new(_("occurrence"));
+    gtk_box_pack_start(GTK_BOX(apptw->appRecur_int_hbox)
+            , apptw->appRecur_int_spin_label2, FALSE, FALSE, 0);
+    xfcalendar_table_add_row(apptw->appTableRecur
+            , apptw->appRecur_int_label, apptw->appRecur_int_hbox, row++
+            , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
+            , (GtkAttachOptions) (0));
+    gtk_tooltips_set_tip(apptw->appTooltips, apptw->appRecur_int_spin
+            , _("Limit frequency to certain interval. For example:\n Every third day: Frequency = Daily and Interval = 3")
+            , NULL);
+
+    apptw->appRecur_limit_label = gtk_label_new(_("Limit"));
+    apptw->appRecur_limit_rb = gtk_radio_button_new_with_label(NULL
             , _("Repeat forever"));
     xfcalendar_table_add_row(apptw->appTableRecur
-            , NULL, apptw->appRecur_repeat_rb, 2
+            , apptw->appRecur_limit_label, apptw->appRecur_limit_rb, row++
             , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
             , (GtkAttachOptions) (0));
 
     apptw->appRecur_count_hbox = gtk_hbox_new(FALSE, 0);
     apptw->appRecur_count_rb = gtk_radio_button_new_with_mnemonic_from_widget(
-            GTK_RADIO_BUTTON(apptw->appRecur_repeat_rb)
-            , _("Repeat "));
+            GTK_RADIO_BUTTON(apptw->appRecur_limit_rb), _("Repeat "));
     gtk_box_pack_start(GTK_BOX(apptw->appRecur_count_hbox)
             , apptw->appRecur_count_rb, FALSE, FALSE, 0);
     apptw->appRecur_count_spin = gtk_spin_button_new_with_range(1, 100, 1);
-    gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(apptw->appRecur_count_spin), TRUE);
+    gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(apptw->appRecur_count_spin)
+            , TRUE);
     gtk_box_pack_start(GTK_BOX(apptw->appRecur_count_hbox)
             , apptw->appRecur_count_spin, FALSE, FALSE, 0);
-    label = gtk_label_new(_("times"));
-    gtk_box_pack_start(GTK_BOX(apptw->appRecur_count_hbox), label
-            , FALSE, FALSE, 5);
+    apptw->appRecur_count_label = gtk_label_new(_("times"));
+    gtk_box_pack_start(GTK_BOX(apptw->appRecur_count_hbox)
+            , apptw->appRecur_count_label, FALSE, FALSE, 5);
     xfcalendar_table_add_row(apptw->appTableRecur
-            , NULL, apptw->appRecur_count_hbox, 3
+            , NULL, apptw->appRecur_count_hbox, row++
             , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
             , (GtkAttachOptions) (0));
 
     apptw->appRecur_until_hbox = gtk_hbox_new(FALSE, 0);
     apptw->appRecur_until_rb = gtk_radio_button_new_with_mnemonic_from_widget(
-            GTK_RADIO_BUTTON(apptw->appRecur_repeat_rb)
-            , _("Repeat until "));
+            GTK_RADIO_BUTTON(apptw->appRecur_limit_rb), _("Repeat until "));
     gtk_box_pack_start(GTK_BOX(apptw->appRecur_until_hbox)
             , apptw->appRecur_until_rb, FALSE, FALSE, 0);
     apptw->appRecur_until_button = gtk_button_new();
     gtk_box_pack_start(GTK_BOX(apptw->appRecur_until_hbox)
             , apptw->appRecur_until_button, FALSE, FALSE, 0);
     xfcalendar_table_add_row(apptw->appTableRecur
-            , NULL, apptw->appRecur_until_hbox, 4
+            , NULL, apptw->appRecur_until_hbox, row++
+            , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
+            , (GtkAttachOptions) (0));
+
+    apptw->appRecur_byday_label = gtk_label_new(_("Weekdays"));
+    apptw->appRecur_byday_hbox = gtk_hbox_new(TRUE, 0);
+    for (i=0; i <= 6; i++) {
+        apptw->appRecur_byday_cb[i] = 
+                gtk_check_button_new_with_mnemonic(weekday_array[i]);
+        gtk_box_pack_start(GTK_BOX(apptw->appRecur_byday_hbox)
+                , apptw->appRecur_byday_cb[i], FALSE, FALSE, 0);
+    }
+    xfcalendar_table_add_row(apptw->appTableRecur
+            , apptw->appRecur_byday_label, apptw->appRecur_byday_hbox, row++
+            , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
+            , (GtkAttachOptions) (0));
+
+    apptw->appRecur_byday_spin_label = gtk_label_new(_("Which day"));
+    apptw->appRecur_byday_spin_hbox = gtk_hbox_new(TRUE, 0);
+    for (i=0; i <= 6; i++) {
+        apptw->appRecur_byday_spin[i] = 
+                gtk_spin_button_new_with_range(-9, 9, 1);
+        gtk_box_pack_start(GTK_BOX(apptw->appRecur_byday_spin_hbox)
+                , apptw->appRecur_byday_spin[i], FALSE, FALSE, 0);
+        gtk_tooltips_set_tip(apptw->appTooltips, apptw->appRecur_byday_spin[i]
+                , _("Specify which weekday for monthly and yearly events.\n For example:\n Second Wednesday each month:\n\tFrequency = Monthly,\n\tWeekdays = check only Wednesday,\n\tWhich day = select 2 from the number below Wednesday")
+                , NULL);
+    }
+    xfcalendar_table_add_row(apptw->appTableRecur
+            , apptw->appRecur_byday_spin_label
+            , apptw->appRecur_byday_spin_hbox, row++
             , (GtkAttachOptions) (GTK_EXPAND | GTK_FILL)
             , (GtkAttachOptions) (0));
 }
@@ -1542,9 +1752,10 @@ create_appt_win_tab_recurrence(appt_win *apptw)
 appt_win 
 *create_appt_win(char *action, char *par, eventlist_win *event_list)
 {
-    /* main window creation and base elements */
+    int i;
     appt_win *apptw = g_new(appt_win, 1);
 
+    /* main window creation and base elements */
     apptw->xf_uid = NULL;
     apptw->eventlist = event_list;    /* Keep track of the parent, if any */
     apptw->appointment_changed = FALSE;
@@ -1667,24 +1878,41 @@ appt_win
     g_signal_connect((gpointer) apptw->appSoundRepeat_checkbutton, "clicked",
             G_CALLBACK(app_checkbutton_clicked_cb), apptw);
 
-    g_signal_connect((gpointer) apptw->appRecur_cb, "changed",
+    g_signal_connect((gpointer) apptw->appRecur_freq_cb, "changed",
             G_CALLBACK(on_app_combobox_changed_cb), apptw);
 
-    g_signal_connect((gpointer) apptw->appRecur_repeat_rb, "clicked",
-            G_CALLBACK(app_checkbutton_clicked_cb), apptw);
+    g_signal_connect((gpointer) apptw->appRecur_limit_rb, "clicked",
+            G_CALLBACK(app_recur_checkbutton_clicked_cb), apptw);
 
     g_signal_connect((gpointer) apptw->appRecur_count_rb, "clicked",
-            G_CALLBACK(app_checkbutton_clicked_cb), apptw);
+            G_CALLBACK(app_recur_checkbutton_clicked_cb), apptw);
 
     g_signal_connect((gpointer) apptw->appRecur_count_spin, "value-changed",
             G_CALLBACK(on_app_spin_button_changed_cb), apptw);
 
-    g_signal_connect((gpointer) apptw->appRecur_count_rb, "clicked",
-            G_CALLBACK(app_checkbutton_clicked_cb), apptw);
+    g_signal_connect((gpointer) apptw->appRecur_until_rb, "clicked",
+            G_CALLBACK(app_recur_checkbutton_clicked_cb), apptw);
+
+    g_signal_connect((gpointer) apptw->appRecur_feature_normal_rb, "clicked",
+            G_CALLBACK(app_recur_feature_checkbutton_clicked_cb), apptw);
+
+    g_signal_connect((gpointer) apptw->appRecur_feature_advanced_rb, "clicked",
+            G_CALLBACK(app_recur_feature_checkbutton_clicked_cb), apptw);
 
     g_signal_connect((gpointer) apptw->appRecur_until_button, "clicked",
             G_CALLBACK(on_appStartEndDate_clicked_cb), apptw);
 
+
+    for (i=0; i <= 6; i++) {
+        g_signal_connect((gpointer) apptw->appRecur_byday_cb[i], "clicked",
+                G_CALLBACK(app_checkbutton_clicked_cb), apptw);
+        g_signal_connect((gpointer) apptw->appRecur_byday_spin[i], 
+                "value-changed",
+                G_CALLBACK(on_app_spin_button_changed_cb), apptw);
+    }
+    g_signal_connect((gpointer) apptw->appRecur_int_spin, "value-changed",
+            G_CALLBACK(on_app_spin_button_changed_cb), apptw);
+
     g_signal_connect((gpointer) apptw->appAvailability_cb, "changed",
             G_CALLBACK(on_app_combobox_changed_cb), apptw);
 
@@ -1704,7 +1932,17 @@ appt_win
             G_CALLBACK(on_app_entry_changed_cb), apptw);
 
     fill_appt_window(apptw, action, par);
+
     gtk_widget_show_all(apptw->appWindow);
+    if (gtk_toggle_button_get_active(
+            GTK_TOGGLE_BUTTON(apptw->appRecur_feature_normal_rb))) {
+        gtk_widget_hide(apptw->appRecur_int_label);
+        gtk_widget_hide(apptw->appRecur_int_hbox);
+        gtk_widget_hide(apptw->appRecur_byday_label);
+        gtk_widget_hide(apptw->appRecur_byday_hbox);
+        gtk_widget_hide(apptw->appRecur_byday_spin_label);
+        gtk_widget_hide(apptw->appRecur_byday_spin_hbox);
+    }
 
     return apptw;
 }
