@@ -1,6 +1,7 @@
 /* tray_icon.c
  *
- * (C) 2004 Mickal Graf
+ * (C) 2004-2006 Mickal Graf
+ * (C)      2006 Juha Kautto
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -103,6 +104,7 @@ GdkPixbuf *create_icon(CalWin *xfcal, gint x, gint y)
   GdkGC *pic1_gc1, *pic1_gc2;
   GdkColormap *pic1_cmap;
   GdkColor color;
+  GdkVisual *pic1_vis;
   PangoLayout *pl_day, *pl_head, *pl_month;
   gint width = 0, height = 0, depth = 16;
   gint red = 239, green = 235, blue = 230;
@@ -119,12 +121,12 @@ GdkPixbuf *create_icon(CalWin *xfcal, gint x, gint y)
                       , "small", "x-small", "xx-small", "END"};
 
   if (x <= 12 || y <= 12) {
-      g_message("orage create_icon: too small icon size, using static icon\n");
+      g_message("Orage **: Too small icon size, using static icon\n");
       pixbuf = xfce_themed_icon_load("xfcalendar", 16);
       return(pixbuf);
   }
   if (icon_size_x == 0 || icon_size_y == 0) { /* signal to use static icon */
-      g_message("orage create_icon: using static icon\n");
+      g_message("Orage **: Icon size set to zero, using static icon\n");
       pixbuf = xfce_themed_icon_load("xfcalendar", x);
       return(pixbuf);
   }
@@ -132,9 +134,11 @@ GdkPixbuf *create_icon(CalWin *xfcal, gint x, gint y)
   t = orage_localtime();
   width = x; 
   height = y;
-  depth = gdk_visual_get_best_depth();
+  pic1_cmap = gdk_colormap_get_system();
+  pic1_vis = gdk_colormap_get_visual(pic1_cmap);
+  depth = pic1_vis->depth;
   pic1 = gdk_pixmap_new(NULL, width, height, depth);
-  pic1_cmap = gdk_screen_get_default_colormap(gdk_screen_get_default());
+  gdk_drawable_set_colormap(pic1, pic1_cmap);
   /* pic1_cmap = gtk_widget_get_colormap(xfcal->mWindow); */
   pic1_gc1 = gdk_gc_new(pic1);
   pic1_gc2 = gdk_gc_new(pic1);
@@ -166,9 +170,7 @@ GdkPixbuf *create_icon(CalWin *xfcal, gint x, gint y)
   pango_layout_get_extents(pl_head, &real_rect, &log_rect);
   x_offset = (width - PANGO_PIXELS(log_rect.width) - 2)/2;
   y_offset = -2;
-  /*
-  g_print("orage offset x=%d y=%d height=%d text height=%d real text height=%d\n" , x_offset, y_offset, height, PANGO_PIXELS(log_rect.height), PANGO_PIXELS(real_rect.height));
-  */
+  /* g_print("orage offset x=%d y=%d height=%d text height=%d real text height=%d\n" , x_offset, y_offset, height, PANGO_PIXELS(log_rect.height), PANGO_PIXELS(real_rect.height)); */
   if (x_offset > 0 && (height-PANGO_PIXELS(log_rect.height)-y_offset) > 0) {
       draw_head = TRUE; /* fits */
       x_head = x_offset;
@@ -189,9 +191,6 @@ GdkPixbuf *create_icon(CalWin *xfcal, gint x, gint y)
   pango_layout_get_extents(pl_month, &real_rect, &log_rect);
   x_offset = (width - PANGO_PIXELS(real_rect.width) - 2)/2;
   y_offset = (height - PANGO_PIXELS(log_rect.height) - 2);
-  /*
-  g_print("month offset x=%d y=%d height=%d text height=%d real text height=%d\n" , x_offset, y_offset, height, PANGO_PIXELS(log_rect.height), PANGO_PIXELS(real_rect.height));
-  */
   if (x_offset > 0 && (height - y_offset - PANGO_PIXELS(log_rect.height))) {
       draw_month = TRUE; /* fits */
       x_month = x_offset;
@@ -225,9 +224,6 @@ GdkPixbuf *create_icon(CalWin *xfcal, gint x, gint y)
       pango_layout_get_extents(pl_day, &real_rect, &log_rect);
       x_offset = (width - PANGO_PIXELS(log_rect.width))/2;
       y_offset = (height - y_used - PANGO_PIXELS(log_rect.height))/2;
-      /*
-  g_print("day offset x=%d y=%d height=%d text height=%d real text height=%d\n" , x_offset, y_offset, height, PANGO_PIXELS(log_rect.height), PANGO_PIXELS(real_rect.height));
-  */
       } /* for */
       if (x_offset >= 0 && (y_offset) >= 0) { /* it fits */
           draw_dynamic = TRUE;
@@ -302,18 +298,21 @@ XfceTrayIcon* create_TrayIcon(CalWin *xfcal)
    */
   trayMenu = gtk_menu_new();
   menuItem = gtk_image_menu_item_new_with_mnemonic(_("Today"));
-  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem), gtk_image_new_from_stock(GTK_STOCK_HOME, GTK_ICON_SIZE_MENU));
-  g_signal_connect(menuItem, "activate", G_CALLBACK(on_Today_activate),
-		   xfcal);
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem)
+          , gtk_image_new_from_stock(GTK_STOCK_HOME, GTK_ICON_SIZE_MENU));
+  g_signal_connect(menuItem, "activate", G_CALLBACK(on_Today_activate)
+          , xfcal);
   gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
   gtk_widget_show_all(menuItem);
   menuItem = gtk_separator_menu_item_new();
   gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
   gtk_widget_show(menuItem);
 
-  menuItem = gtk_menu_item_new_with_label(_("New appointment"));
-  g_signal_connect(menuItem, "activate", G_CALLBACK(on_new_appointment_activate),
-		   NULL);
+  menuItem = gtk_image_menu_item_new_with_label(_("New appointment"));
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem)
+          , gtk_image_new_from_stock(GTK_STOCK_NEW, GTK_ICON_SIZE_MENU));
+  g_signal_connect(menuItem, "activate"
+          , G_CALLBACK(on_new_appointment_activate), NULL);
   gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
   gtk_widget_show(menuItem);
   menuItem = gtk_separator_menu_item_new();
@@ -321,22 +320,25 @@ XfceTrayIcon* create_TrayIcon(CalWin *xfcal)
   gtk_widget_show(menuItem);
   
   menuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_PREFERENCES, NULL);
-  g_signal_connect(menuItem, "activate", G_CALLBACK(on_preferences_activate),
-		   NULL);
+  g_signal_connect(menuItem, "activate", G_CALLBACK(on_preferences_activate)
+          , NULL);
   gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
   gtk_widget_show(menuItem);
   menuItem = gtk_separator_menu_item_new();
   gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
   gtk_widget_show(menuItem);
 
-  menuItem = gtk_menu_item_new_with_label(_("About Orage"));
-  g_signal_connect(menuItem, "activate", G_CALLBACK(on_about_activate),
-		   xfcal);
+  menuItem = gtk_image_menu_item_new_with_label(_("About Orage"));
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem)
+          , gtk_image_new_from_stock(GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU));
+  g_signal_connect(menuItem, "activate", G_CALLBACK(on_about_activate)
+          , xfcal);
   gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
   gtk_widget_show(menuItem);
   menuItem = gtk_separator_menu_item_new();
   gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
   gtk_widget_show(menuItem);
+
   menuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, NULL);
   g_signal_connect(menuItem, "activate", G_CALLBACK(gtk_main_quit), NULL);
   gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
